import { Message } from 'element-ui'
import FileSaver from 'file-saver';
import XLSX from 'xlsx';

function getBase64(img) {
    function getBase64Image(img, width, height) {
        var canvas = document.createElement("canvas");
        canvas.width = width ? width : img.width;
        canvas.height = height ? height : img.height;
        var ctx = canvas.getContext("2d");
        ctx.drawImage(img, 0, 0, canvas.width, canvas.height);
        var dataURL = canvas.toDataURL();
        return dataURL;
    }
    var image = new Image();
    image.setAttribute('crossOrigin', 'anonymous')
    image.crossOrigin = '';
    image.src = img;
    return new Promise((resolve, reject) => {
        image.onload = function() {
            resolve(getBase64Image(image)); //将base64传给done上传处理
        }
    });
}

export function handleDate(date) {
    let objDate = new Date(date)
    let year = objDate.getFullYear()
    let month = objDate.getMonth() > 9 ? objDate.getMonth() + 1 : '0' + (objDate.getMonth() + 1)
    let day = objDate.getDate() > 9 ? objDate.getDate() : '0' + objDate.getDate()
    return (year + '-' + month + '-' + day)
}

export function fileProcess(fileUrl) {
    getBase64(fileUrl).then(base64 => {
        console.log(base64)
    })
}
// 判断浏览器
export function IEVersion() {
    var userAgent = navigator.userAgent; //取得浏览器的userAgent字符串  
    var isIE = userAgent.indexOf("compatible") > -1 && userAgent.indexOf("MSIE") > -1; //判断是否IE<11浏览器  
    var isEdge = userAgent.indexOf("Edge") > -1 && !isIE; //判断是否IE的Edge浏览器  
    var isIE11 = userAgent.indexOf('Trident') > -1 && userAgent.indexOf("rv:11.0") > -1;
    if (isIE) {
        var reIE = new RegExp("MSIE (\\d+\\.\\d+);");
        reIE.test(userAgent);
        var fIEVersion = parseFloat(RegExp["$1"]);
        if (fIEVersion == 7) {
            return 7;
        } else if (fIEVersion == 8) {
            return 8;
        } else if (fIEVersion == 9) {
            return 9;
        } else if (fIEVersion == 10) {
            return 10;
        } else {
            return 6; //IE版本<=7
        }
    } else if (isEdge) {
        return 'edge'; //edge
    } else if (isIE11) {
        return 11; //IE11  
    } else {
        return "-1"; //不是ie浏览器
    }
}

export const warn = msg => {
    Message({
        message: msg,
        type: 'warning'
    })
    return true
}
export const err = msg => {
    Message({
        message: msg,
        type: 'error'
    })
    return true
}
export const suc = msg => {
    Message({
        message: msg,
        type: 'success'
    })
    return true
}
export const info = msg => {
    Message({
        message: msg,
        type: 'info'
    })
    return true
}

export const cache = (data) => {
    let cache = {}
    return cache.data || (cache.data = data)
}

export function merge() {
    var result = {};

    function assignValue(val, key) {
        if (typeof result[key] === 'object' && typeof val === 'object') {
            result[key] = merge(result[key], val);
        } else {
            result[key] = val;
        }
    }

    for (var i = 0, l = arguments.length; i < l; i++) {
        for (var key in arguments[i]) {
            assignValue(arguments[i][key], key)
        }
    }
    return result;
}

const title = '生态环境应急监测管理系统'
export function getPageTitle(pageTitle) {
    if (pageTitle) {
        return `${pageTitle}-${title}`
    } else {
        return title
    }
}
export function getLocal(key) {
    return localStorage.getItem(key)
}
export function getToken() {
    return localStorage.getItem('token')
}

export function setToken(token) {
    localStorage.setItem('token', token)
    return token
}

export function cacheData(fn, source) {
    if (!Array.isArray(source)) {
        return []
    }
    if (Object.prototype.toString.call(fn) !== '[object Function]') {
        return source
    }
    if (source.length) {
        return source
    } else {
        return fn()
    }
}


export function downLoad(data, headers, type) {
    let filename;
    if (headers['content-disposition']) {
        filename = headers['content-disposition'].match(
            /([A-Z]|%|\d)+/
        )[0];
    } else { filename = '下载文件' }
    filename = decodeURI(filename);
    let blob = new Blob([data]);
    let a = document.createElement('a');
    a.style.display = 'none';
    a.download = `${filename}.${type}`;
    a.href = URL.createObjectURL(blob);
    a.click();
}

export function forEach(target, cb) {

}

// 组件根据dom node导出excel
export function exportExcelNotByPage(node, fileName) {
    /* generate workbook object from table */
    var wb = XLSX.utils.table_to_book(
        node
    );
    /* get binary string as output */
    var wbout = XLSX.write(wb, {
        bookType: 'xlsx',
        bookSST: true,
        type: 'array',
    });
    try {
        FileSaver.saveAs(
            new Blob([wbout], { type: 'application/octet-stream' }),
            fileName
        );
    } catch (e) {
        if (typeof console !== 'undefined') console.log(e, wbout);
    }
    return wbout;
}

export function deepClone(value) {
    if (value == undefined || value == null) {
        return undefined
    }
    if (typeof value == 'string' || typeof value == 'number') {
        return value
    }
    let target;
    if (Array.isArray(value)) {
        target = []
        value.forEach(e => {
            target.push(deepClone(e))
        })
    } else {
        target = {}
        for (var key in value) {
            target[key] = deepClone(value[key])
        }
    }
    return target
}

export function isYes(value) {
    if (typeof value == 'object') {
        return
    }
    if (typeof value == 'string') {
        return value == '1' ? '是' : '否'
    }
    if (typeof value == 'number') {
        return value == 1 ? '是' : '否'
    }
    if (typeof value == 'boolean') {
        return value == true ? '是' : '否'
    }
    if (value == undefined || value == null) {
        return '否'
    }
}
export function urlToFile(url, imageName) {
    return new Promise((resolve, reject) => {
        let path = url.replace(/^http:\/\/([0-9]+\.){3}([0-9]+):[0-9]+/, '')
        var blob = null;
        var xhr = new XMLHttpRequest();
        xhr.open("GET", '/imgapi' + path);
        xhr.setRequestHeader('Accept', 'image/jpeg');
        xhr.responseType = "blob";
        xhr.onload = () => {
            //console.log('111')
            if (xhr.status == 200) {
                blob = xhr.response;
                let imgFile = new File([blob], imageName, { type: 'image/jpeg' });
                resolve(imgFile)
            } else {
                reject('err')
            }
        };
        xhr.send();
    })
}

export function elupload() {
    setTimeout(() => {
        let btns = document.querySelectorAll('.el-upload');
        for (var i = 0; i < btns.length; i++) {
            btns[i].style.display = 'none';
        }
    }, 100);
}